##  Application Fact Sheet Subtypes
The application fact sheet type has optional subtypes. These subtypes are not included in the predefined meta model by default.
  * Business application: The business application subtype is used to clearly distinguish logical applications from microservices and AI agents. You can add this subtype manually or by activating the AI agent extension to the meta model.
    * To learn how to add a fact sheet subtype manually, see [Add Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__add_fact_sheet_subtypes_to_several_fact_sheet_types). Once you’ve added the needed subtypes, also create self-referencing relations between the subtypes. To learn how, see [Fact Sheet Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations?locale=en-US&state=PRODUCTION&version=CLOUD "Relations represent connections between different fact sheets. Learn how to configure basic and advanced relations.").
    * You can add this fact sheet subtype by activating the AI agent extension to the meta model. To learn more about this extension, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
  * Microservice: Microservices are individually deployable building blocks that perform a specific function or task within a larger application, typically self-developed. The microservice fact sheet subtype represents these functional composites of the application. Modeling microservices is helpful in understanding their technical ownership, identifying opportunities for reuse across different applications, and modernizing architecture from monolithic applications to microservices architecture.
Microservices, on their own, don’t answer typical business application questions and cannot exist independently of the business application. They must be related to the business layer through the business application subtype. For guidelines and best practices on modeling microservices, see [Microservice Modeling Guidelines](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for microservices. Learn best practices for tracking their provisioning and dependencies effectively and avoid common antipatterns.").
To learn how to add a fact sheet subtype manually, see [Add Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__add_fact_sheet_subtypes_to_several_fact_sheet_types). Once you’ve added the needed subtypes, also create self-referencing relations between the subtypes. To learn how, see [Fact Sheet Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations?locale=en-US&state=PRODUCTION&version=CLOUD "Relations represent connections between different fact sheets. Learn how to configure basic and advanced relations.").
**Tip**
SAP LeanIX Technology Risk and Compliance customers can enable the self-built software discovery feature to automatically add the microservice fact sheet subtype, along with essential fields and relations. To learn more, see [Workspace Setup for Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Provision the self-built software discovery feature in SAP LeanIX to enable microservice discovery. This extends the meta model with microservice fact sheets, custom relations, and additional context fields.").
  * AI agent: An AI agent is a system that uses a large language model (LLM) to autonomously interact with its environment, reason through multistep tasks, and achieve user-defined goals without explicit direction. You can add this subtype by activating the AI agent extension to the meta model. To learn more about this extension, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
